Date: 2022-10-01T06:40:52+00:00

Actual source code: slepcrgtypes.h
slepc-3.18.0 2022-10-01
Report Typos and Errors

      1: /*
      2:    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      3:    SLEPc - Scalable Library for Eigenvalue Problem Computations
      4:    Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain

      6:    This file is part of SLEPc.
      7:    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
      8:    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      9: */

     11: #if !defined(SLEPCRGTYPES_H)
     12: #define SLEPCRGTYPES_H

     14: /* SUBMANSEC = RG */

     16: /*S
     17:    RG - Region of the complex plane.

     19:    Level: beginner

     21: .seealso: RGCreate()
     22: S*/
     23: typedef struct _p_RG* RG;

     25: #endif